/*
 * $Id: Response.java 292 2006-02-28 23:30:47Z davidb $
 * 
 * Copyright (c) 2005 VeriSign. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer. 2. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution. 3. The name of the author may not
 * be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN
 * NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  
 */

package se.rfc.unbound;

/**
 * This class represents a response to a request. This is either an actual
 * message, or a timeout, or a wakeup.  (Timeouts are final, wakeups are not).
 * 
 * @author davidb
 * @version $Revision: 292 $
 */
public class Response
{
  public static final int OK = 0;
  public static final int TIMEOUT = 1;
  public static final int WAKEUP = 2;
  
  private SMessage mResponse;
  private int mResponseType;
  private int mResponseStatus;
  private Host mSource;
  
  public Response(SMessage m, int status)
  {
    mResponse = m;
    mResponseStatus = status;
  }

  public static Response timeoutResponse()
  {
    return new Response(null, TIMEOUT);
  }
  
  public static Response wakeupResponse()
  {
    return new Response(null, WAKEUP);
  }
  
  /**
   * @return Returns the (cached) response type (ANSWER, REFERRAL, etc.. If
   *         zero, then this response hasn't been typed.
   */
  public int getResponseType()
  {
    return mResponseType;
  }

  /**
   * Cache the response type.
   * @param responseType The response type.
   */
  public void setResponseType(int responseType)
  {
    mResponseType = responseType;
  }

  /**
   * @return Returns the response itself.
   */
  public SMessage getSMessage()
  {
    return mResponse;
  }

  /**
   * @return Returns the response status. If not OK, then there won't be an
   *         actual response message..
   */
  public int getResponseStatus()
  {
    return mResponseStatus;
  }

  /**
   * @return Returns the source.
   */
  public Host getSource()
  {
    return mSource;
  }

  /**
   * @param source The source to set.
   */
  public void setSource(Host source)
  {
    mSource = source;
  }
  
}
